@@ -28,6 +28,7 @@
 #include "goaoauth2provider.h"
 #include "goafoursquareprovider.h"
 #include "goaobjectskeletonutils.h"
+#include "goarestproxy.h"
 
 struct _GoaFoursquareProvider
 {
@@ -135,7 +136,7 @@ get_identity_sync (GoaOAuth2Provider  *oauth2_provider,
 
   /* TODO: cancellable */
 
-  proxy = rest_proxy_new ("https://api.foursquare.com/v2/users/self", FALSE);
+  proxy = goa_rest_proxy_new ("https://api.foursquare.com/v2/users/self", FALSE);
   call = rest_proxy_new_call (proxy);
   rest_proxy_call_set_method (call, "GET");
   rest_proxy_call_add_param (call, "oauth_token", access_token);
@@ -174,10 +175,20 @@ get_identity_sync (GoaOAuth2Provider  *oauth2_provider,
     }
 
   json_object = json_node_get_object (json_parser_get_root (parser));
-  json_object = json_object_get_object_member (json_object, "response");
-  if (json_object == NULL)
+  if (!json_object_has_member (json_object, "response"))
     {
-      g_warning ("Did not find response object in JSON data");
+      g_warning ("Did not find response in JSON data");
+      g_set_error (error,
+                   GOA_ERROR,
+                   GOA_ERROR_FAILED,
+                   _("Could not parse response"));
+      goto out;
+    }
+
+  json_object = json_object_get_object_member (json_object, "response");
+  if (!json_object_has_member (json_object, "user"))
+    {
+      g_warning ("Did not find response.user in JSON data");
       g_set_error (error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED,
@@ -186,9 +197,18 @@ get_identity_sync (GoaOAuth2Provider  *oauth2_provider,
     }
 
   json_object = json_object_get_object_member (json_object, "user");
-  if (json_object == NULL)
+  if (!json_object_has_member (json_object, "id"))
     {
-      g_warning ("Did not find user object in JSON data");
+      g_warning ("Did not find response.user.id in JSON data");
+      g_set_error (error,
+                   GOA_ERROR,
+                   GOA_ERROR_FAILED,
+                   _("Could not parse response"));
+      goto out;
+    }
+  if (!json_object_has_member (json_object, "contact"))
+    {
+      g_warning ("Did not find response.user.contact in JSON data");
       g_set_error (error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED,
@@ -197,20 +217,11 @@ get_identity_sync (GoaOAuth2Provider  *oauth2_provider,
     }
 
   id = g_strdup (json_object_get_string_member (json_object, "id"));
-  if (id == NULL)
-    {
-      g_warning ("Did not find id in JSON data");
-      g_set_error (error,
-                   GOA_ERROR,
-                   GOA_ERROR_FAILED,
-                   _("Could not parse response"));
-      goto out;
-    }
 
   json_object = json_object_get_object_member (json_object, "contact");
-  if (json_object == NULL)
+  if (!json_object_has_member (json_object, "email"))
     {
-      g_warning ("Did not find contact object in JSON data");
+      g_warning ("Did not find response.user.contact.email in JSON data");
       g_set_error (error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED,
@@ -219,15 +230,6 @@ get_identity_sync (GoaOAuth2Provider  *oauth2_provider,
     }
 
   presentation_identity = g_strdup (json_object_get_string_member (json_object, "email"));
-  if (presentation_identity == NULL)
-    {
-      g_warning ("Did not find email in JSON data");
-      g_set_error (error,
-                   GOA_ERROR,
-                   GOA_ERROR_FAILED,
-                   _("Could not parse response"));
-      goto out;
-    }
 
   ret = id;
   id = NULL;
