@@ -27,6 +27,7 @@
 #include "goaprovider-priv.h"
 #include "goawindowsliveprovider.h"
 #include "goaobjectskeletonutils.h"
+#include "goarestproxy.h"
 
 struct _GoaWindowsLiveProvider
 {
@@ -143,7 +144,7 @@ get_identity_sync (GoaOAuth2Provider  *oauth2_provider,
 
   /* TODO: cancellable */
 
-  proxy = rest_proxy_new ("https://apis.live.net/v5.0/me", FALSE);
+  proxy = goa_rest_proxy_new ("https://apis.live.net/v5.0/me", FALSE);
   call = rest_proxy_new_call (proxy);
   rest_proxy_call_set_method (call, "GET");
   rest_proxy_call_add_param (call, "access_token", access_token);
@@ -179,8 +180,7 @@ get_identity_sync (GoaOAuth2Provider  *oauth2_provider,
     }
 
   json_object = json_node_get_object (json_parser_get_root (parser));
-  id = g_strdup (json_object_get_string_member (json_object, "id"));
-  if (id == NULL)
+  if (!json_object_has_member (json_object, "id"))
     {
       g_warning ("Did not find id in JSON data");
       g_set_error (error,
@@ -189,10 +189,20 @@ get_identity_sync (GoaOAuth2Provider  *oauth2_provider,
                    _("Could not parse response"));
       goto out;
     }
+  if (!json_object_has_member (json_object, "emails"))
+    {
+      g_warning ("Did not find emails in JSON data");
+      g_set_error (error,
+                   GOA_ERROR,
+                   GOA_ERROR_FAILED,
+                   _("Could not parse response"));
+      goto out;
+    }
+
+  id = g_strdup (json_object_get_string_member (json_object, "id"));
 
   json_object = json_object_get_object_member (json_object, "emails");
-  presentation_identity = g_strdup (json_object_get_string_member (json_object, "account"));
-  if (presentation_identity == NULL)
+  if (!json_object_has_member (json_object, "account"))
     {
       g_warning ("Did not find emails.account in JSON data");
       g_set_error (error,
@@ -202,6 +212,8 @@ get_identity_sync (GoaOAuth2Provider  *oauth2_provider,
       goto out;
     }
 
+  presentation_identity = g_strdup (json_object_get_string_member (json_object, "account"));
+
   ret = id;
   id = NULL;
   if (out_presentation_identity != NULL)
